@@ -367,12 +367,12 @@ bool TaskEditorDialog::canReduceMinutesGroup() {
 
 void TaskEditorDialog::emptyMinutesGroup() {
 
-	logDebug() << "Empty minutes layout" << endl;
+	logDebug() << "Empty minutes layout";
 
 	for (int minuteIndex = 0; minuteIndex<=minuteTotal; ++minuteIndex ) {
 		minutesLayout->removeWidget(minuteButtons[minuteIndex]);
 		minuteButtons[minuteIndex]->hide();
-		logDebug() << "Layout count" << minutesLayout->count() << endl;
+		logDebug() << "Layout count" << minutesLayout->count();
 	}
 
 	minutesLayout->removeItem(minutesPreselectionLayout);
@@ -391,7 +391,7 @@ void TaskEditorDialog::increaseMinutesGroup() {
 	*/
 	emptyMinutesGroup();
 
-	logDebug() << "Show all minutes" << endl;
+	logDebug() << "Show all minutes";
 
 	int minuteIndex = 0;
 	for (int row = 0; row < (minuteTotal+1)/minutePerColumn; ++row) {
@@ -409,7 +409,7 @@ void TaskEditorDialog::increaseMinutesGroup() {
 }
 
 void TaskEditorDialog::reduceMinutesGroup() {
-	logDebug() << "Reducing view" << endl;
+	logDebug() << "Reducing view";
 
 	emptyMinutesGroup();
 
@@ -428,7 +428,7 @@ void TaskEditorDialog::reduceMinutesGroup() {
 			}
 		}
 		else {
-			logDebug() << "Reducing id" << minuteIndex << endl;
+			logDebug() << "Reducing id" << minuteIndex;
 			ctTask->minute.setEnabled(minuteIndex, false);
 			minuteButtons[minuteIndex]->setChecked(false);
 
@@ -454,7 +454,7 @@ NumberPushButton* TaskEditorDialog::createMinuteButton(int minuteIndex) {
 }
 
 void TaskEditorDialog::createMinutesGroup(QWidget* main) {
-	logDebug() << "Creating minutes group" << endl;
+	logDebug() << "Creating minutes group";
 
 	minutesGroup = new QGroupBox( i18n("Minutes"), main);
 
@@ -495,7 +495,7 @@ void TaskEditorDialog::createMinutesGroup(QWidget* main) {
 		reduceMinutesGroup();
 	}
 
-	logDebug() << "Minutes group created" << endl;
+	logDebug() << "Minutes group created";
 }
 
 NumberPushButton* TaskEditorDialog::createHourButton(QGroupBox* hoursGroup, int hour) {
@@ -512,7 +512,7 @@ NumberPushButton* TaskEditorDialog::createHourButton(QGroupBox* hoursGroup, int
 
 QGroupBox* TaskEditorDialog::createHoursGroup(QWidget* main) {
 
-	logDebug() << "Creating hours group" << endl;
+	logDebug() << "Creating hours group";
 	QGroupBox* hoursGroup = new QGroupBox(i18n("Hours"), main);
 
 	QGridLayout* hoursLayout = new QGridLayout(hoursGroup); //5 x 7
@@ -545,7 +545,7 @@ QGroupBox* TaskEditorDialog::createHoursGroup(QWidget* main) {
 	connect(allHours, &SetOrClearAllButton::clicked, this, &TaskEditorDialog::slotAllHours);
 	connect(allHours, &SetOrClearAllButton::clicked, this, &TaskEditorDialog::slotWizard);
 
-	logDebug() << "Create hours group" << endl;
+	logDebug() << "Create hours group";
 	return hoursGroup;
 }
 
@@ -728,7 +728,7 @@ bool TaskEditorDialog::checkCommand() {
 	QString path = pathCommand.at(0);
 	QString binaryCommand = pathCommand.at(1);
 
-	logDebug() << "Looking for " << binaryCommand << "in" << path << endl;
+	logDebug() << "Looking for " << binaryCommand << "in" << path;
 
 	bool found = false;
 	bool exec = false;
@@ -977,7 +977,7 @@ void TaskEditorDialog::slotHourChanged() {
 void TaskEditorDialog::slotMinutesPreselection(int index) {
 	QVariant itemData = minutesPreselection->itemData(index);
 	int step = itemData.toInt();
-	logDebug() << "Selected step " << step << endl;
+	logDebug() << "Selected step " << step;
 
 	if (step == -1) {
 		//Unselect everything
